@@ -49,6 +49,9 @@ pub struct CondaOutputsParams {
     /// The possible variants by the pixi workspace.
     pub variant_configuration: Option<BTreeMap<String, Vec<String>>>,
 
+    /// The variant file paths that were provided by the pixi workspace.
+    pub variant_files: Option<Vec<PathBuf>>,
+
     /// A directory that can be used by the backend to store files for
     /// subsequent requests. This directory is unique for each separate source
     /// dependency.
