@@ -313,7 +313,7 @@ fn print_package_info<W: Write>(
         console::style(format_additional_builds_string(other_builds))
     );
 
-    writeln!(out, "{}", package_info)?;
+    writeln!(out, "{package_info}")?;
     writeln!(out, "{}\n", "-".repeat(package_info.chars().count()))?;
 
     writeln!(
@@ -381,7 +381,7 @@ fn print_package_info<W: Write>(
     )?;
 
     let md5 = match package.package_record.md5 {
-        Some(md5) => format!("{:x}", md5),
+        Some(md5) => format!("{md5:x}"),
         None => "Not available".to_string(),
     };
     writeln!(
@@ -392,7 +392,7 @@ fn print_package_info<W: Write>(
     )?;
 
     let sha256 = match package.package_record.sha256 {
-        Some(sha256) => format!("{:x}", sha256),
+        Some(sha256) => format!("{sha256:x}"),
         None => "Not available".to_string(),
     };
     writeln!(
@@ -404,7 +404,7 @@ fn print_package_info<W: Write>(
 
     writeln!(out, "\nDependencies:")?;
     for dependency in package.package_record.depends {
-        writeln!(out, " - {}", dependency)?;
+        writeln!(out, " - {dependency}")?;
     }
 
     if let Some(run_exports) = package.package_record.run_exports.as_ref() {
@@ -413,7 +413,7 @@ fn print_package_info<W: Write>(
             if !run_exports.is_empty() {
                 writeln!(out, "  {name}:")?;
                 for run_export in run_exports {
-                    writeln!(out, "   - {}", run_export)?;
+                    writeln!(out, "   - {run_export}")?;
                 }
             }
             Ok::<(), std::io::Error>(())
