@@ -182,7 +182,7 @@ pub async fn execute(args: Args) -> miette::Result<()> {
         let diff = LockFileDiff::from_lock_files(loaded_lock_file, &lock_file);
         let json_diff = LockFileJsonDiff::new(Some(workspace.named_environments()), diff);
         let json = serde_json::to_string_pretty(&json_diff).expect("failed to convert to json");
-        println!("{}", json);
+        println!("{json}");
     } else if diff.is_empty() {
         eprintln!(
             "{}Lock-file was already up-to-date",
