@@ -31,6 +31,11 @@ pub struct Args {
     /// Defaults to the default environment.
     #[arg(short, long)]
     pub environment: Option<String>,
+
+    /// The name to use for the rendered conda environment.
+    /// Defaults to the environment name.
+    #[arg(short, long)]
+    pub name: Option<String>,
 }
 
 fn format_pip_extras(extras: &[ExtraName]) -> String {
@@ -128,11 +133,12 @@ fn build_env_yaml(
     platform: &Platform,
     environment: &Environment,
     config: &ChannelConfig,
+    name: String,
 ) -> miette::Result<EnvironmentYaml> {
     let channels =
         channels_with_nodefaults(environment.channels().into_iter().cloned().collect_vec());
     let mut env_yaml = rattler_conda_types::EnvironmentYaml {
-        name: Some(environment.name().as_str().to_string()),
+        name: Some(name),
         channels,
         ..Default::default()
     };
@@ -228,8 +234,16 @@ pub async fn execute(args: Args) -> miette::Result<()> {
     let environment = workspace.environment_from_name_or_env_var(args.environment)?;
     let platform = args.platform.unwrap_or_else(|| environment.best_platform());
     let config = workspace.config();
+    let name = args
+        .name
+        .unwrap_or_else(|| environment.name().as_str().to_string());
 
-    let env_yaml = build_env_yaml(&platform, &environment, config.global_channel_config())?;
+    let env_yaml = build_env_yaml(
+        &platform,
+        &environment,
+        config.global_channel_config(),
+        name,
+    )?;
 
     if let Some(output_path) = args.output_path {
         env_yaml
@@ -259,6 +273,7 @@ mod tests {
             platform: Some(Platform::Osx64),
             environment: Some("default".to_string()),
             workspace_config: WorkspaceConfig::default(),
+            name: None,
         };
         let environment = workspace
             .environment_from_name_or_env_var(args.environment)
@@ -269,6 +284,7 @@ mod tests {
             &platform,
             &environment,
             workspace.config().global_channel_config(),
+            environment.name().as_str().to_string(),
         );
         insta::assert_snapshot!(
             "test_export_conda_env_yaml",
@@ -285,6 +301,7 @@ mod tests {
             platform: None,
             environment: Some("default".to_string()),
             workspace_config: WorkspaceConfig::default(),
+            name: None,
         };
         let environment = workspace
             .environment_from_name_or_env_var(args.environment)
@@ -295,6 +312,7 @@ mod tests {
             &platform,
             &environment,
             workspace.config().global_channel_config(),
+            environment.name().as_str().to_string(),
         );
         insta::assert_snapshot!(
             "test_export_conda_env_yaml_with_pip_extras",
@@ -312,6 +330,7 @@ mod tests {
             platform: None,
             environment: Some("default".to_string()),
             workspace_config: WorkspaceConfig::default(),
+            name: None,
         };
         let environment = workspace
             .environment_from_name_or_env_var(args.environment)
@@ -322,6 +341,7 @@ mod tests {
             &platform,
             &environment,
             workspace.config().global_channel_config(),
+            environment.name().as_str().to_string(),
         );
         insta::assert_snapshot!(
             "test_export_conda_env_yaml_with_source_editable",
@@ -336,7 +356,7 @@ mod tests {
         let workspace = match Workspace::from_path(&path) {
             Ok(workspace) => workspace,
             Err(err) => {
-                panic!("Failed to load workspace: {:?}", err);
+                panic!("Failed to load workspace: {err:?}");
             }
         };
         let args = Args {
@@ -344,6 +364,7 @@ mod tests {
             platform: None,
             environment: Some("alternative".to_string()),
             workspace_config: WorkspaceConfig::default(),
+            name: None,
         };
         let environment = workspace
             .environment_from_name_or_env_var(args.environment)
@@ -354,6 +375,7 @@ mod tests {
             &platform,
             &environment,
             workspace.config().global_channel_config(),
+            environment.name().as_str().to_string(),
         );
         insta::assert_snapshot!(
             "test_export_conda_env_yaml_with_pip_custom_registry",
@@ -371,6 +393,7 @@ mod tests {
             platform: None,
             environment: Some("default".to_string()),
             workspace_config: WorkspaceConfig::default(),
+            name: None,
         };
         let environment = workspace
             .environment_from_name_or_env_var(args.environment)
@@ -381,6 +404,7 @@ mod tests {
             &platform,
             &environment,
             workspace.config().global_channel_config(),
+            environment.name().as_str().to_string(),
         );
         insta::assert_snapshot!(
             "test_export_conda_env_yaml_with_pip_find_links",
@@ -397,6 +421,7 @@ mod tests {
             platform: Some(Platform::OsxArm64),
             environment: Some("default".to_string()),
             workspace_config: WorkspaceConfig::default(),
+            name: None,
         };
         let environment = workspace
             .environment_from_name_or_env_var(args.environment)
@@ -407,6 +432,7 @@ mod tests {
             &platform,
             &environment,
             workspace.config().global_channel_config(),
+            environment.name().as_str().to_string(),
         );
         insta::assert_snapshot!(
             "test_export_conda_env_yaml_pyproject_panic",
@@ -431,6 +457,7 @@ mod tests {
             platform: Some(Platform::Osx64),
             environment: None,
             workspace_config: WorkspaceConfig::default(),
+            name: None,
         };
         let environment = workspace
             .environment_from_name_or_env_var(args.environment)
@@ -441,6 +468,7 @@ mod tests {
             &platform,
             &environment,
             workspace.config().global_channel_config(),
+            environment.name().as_str().to_string(),
         );
         insta::assert_snapshot!(
             "test_export_conda_env_yaml_with_defaults",
@@ -464,4 +492,34 @@ mod tests {
             ]
         );
     }
+
+    #[test]
+    fn test_specify_output_name() {
+        let path = Path::new(env!("CARGO_WORKSPACE_DIR"))
+            .join("tests/data/mock-projects/test-project-export/pixi.toml");
+        let workspace = Workspace::from_path(&path).unwrap();
+        let env_name = "custom_env_name".to_string();
+        let args = Args {
+            output_path: None,
+            platform: Some(Platform::Osx64),
+            environment: Some("default".to_string()),
+            workspace_config: WorkspaceConfig::default(),
+            name: Some(env_name.clone()),
+        };
+        let environment = workspace
+            .environment_from_name_or_env_var(args.environment)
+            .unwrap();
+        let platform = args.platform.unwrap_or_else(|| environment.best_platform());
+
+        let env_yaml = build_env_yaml(
+            &platform,
+            &environment,
+            workspace.config().global_channel_config(),
+            env_name,
+        );
+        insta::assert_snapshot!(
+            "test_export_conda_env_yaml_custom_name",
+            env_yaml.unwrap().to_yaml_string()
+        );
+    }
 }
