@@ -61,7 +61,7 @@ impl CommandDispatcherProcessor {
                 .map(move |result| {
                     TaskResult::InstallPixiEnvironment(
                         pending_env_id,
-                        result.unwrap_or(Err(CommandDispatcherError::Cancelled)),
+                        Box::new(result.unwrap_or(Err(CommandDispatcherError::Cancelled))),
                     )
                 })
                 .boxed_local(),
