@@ -54,10 +54,10 @@ mod source_metadata;
 
 pub use backend_source_build::{
     BackendBuiltSource, BackendSourceBuildError, BackendSourceBuildMethod,
-    BackendSourceBuildPrefix, BackendSourceBuildSpec, BackendSourceBuildV0Method,
-    BackendSourceBuildV1Method,
+    BackendSourceBuildPrefix, BackendSourceBuildSpec, BackendSourceBuildV1Method,
 };
 pub use build::BuildEnvironment;
+pub use build_backend_metadata::calculate_additional_glob_hash;
 pub use build_backend_metadata::{
     BuildBackendMetadata, BuildBackendMetadataError, BuildBackendMetadataSpec,
 };
