@@ -227,7 +227,7 @@ pub enum SolveCondaEnvironmentError {
         platform: Platform,
         #[source]
         #[diagnostic_source]
-        source: CommandDispatcherError<SolvePixiEnvironmentError>,
+        source: Box<CommandDispatcherError<SolvePixiEnvironmentError>>,
     },
 
     #[error(transparent)]
@@ -235,7 +235,7 @@ pub enum SolveCondaEnvironmentError {
     PypiMappingFailed(Box<dyn Diagnostic + Send + Sync + 'static>),
 
     #[error(transparent)]
-    ParseChannels(#[from] ParseChannelError),
+    ParseChannels(#[from] Box<ParseChannelError>),
 
     #[error(transparent)]
     #[diagnostic(transparent)]
@@ -1765,7 +1765,7 @@ impl<'p> UpdateContext<'p> {
             builder.set_options(
                 &environment_name,
                 rattler_lock::SolveOptions {
-                    strategy: grouped_env.solve_strategy(),
+                    strategy: grouped_env.solve_strategy().into(),
                     channel_priority: grouped_env
                         .channel_priority()
                         .unwrap_or_default()
@@ -1914,7 +1914,7 @@ async fn spawn_solve_conda_environment_task(
 
     // Get solve options
     let exclude_newer = group.exclude_newer();
-    let strategy = group.solve_strategy();
+    let strategy = group.solve_strategy().into();
 
     // Get the environment name
     let group_name = group.name();
@@ -1952,7 +1952,8 @@ async fn spawn_solve_conda_environment_task(
     let channels = channels
         .iter()
         .map(|c| c.clone().into_base_url(&channel_config))
-        .collect::<Result<Vec<_>, _>>()?;
+        .collect::<Result<Vec<_>, _>>()
+        .map_err(Box::new)?;
 
     // Determine the build variants
     let VariantConfig {
@@ -1983,7 +1984,7 @@ async fn spawn_solve_conda_environment_task(
         .map_err(|source| SolveCondaEnvironmentError::SolveFailed {
             environment_name: group_name.clone(),
             platform,
-            source,
+            source: Box::new(source),
         })?;
 
     // Add purl's for the conda packages that are also available as pypi packages if
@@ -2240,6 +2241,7 @@ async fn spawn_solve_pypi_task<'p>(
     };
 
     let environment_name = grouped_environment.name().clone();
+    let solve_strategy = grouped_environment.solve_strategy();
 
     let pixi_solve_records = &repodata_records.records;
     let locked_pypi_records = &locked_pypi_packages.records;
@@ -2279,6 +2281,7 @@ async fn spawn_solve_pypi_task<'p>(
             environment,
             disallow_install_conda_prefix,
             exclude_newer,
+            solve_strategy,
         )
         .await
         .with_context(|| {
