@@ -940,4 +940,90 @@ mod tests {
             Platform::Win32
         );
     }
+
+    #[test]
+    pub fn test_solve_strategy() {
+        let contents = r#"
+        [project]
+        name = "foo"
+        platforms = []
+        channels = []
+        solve-strategy = "lowest-direct"
+
+        [feature.lowest]
+        solve-strategy = "lowest"
+
+        [feature.highest]
+        solve-strategy = "highest"
+        
+        [feature.no_strategy]
+
+        [environments]
+        lowest = ["lowest"]
+        highest = ["highest"]
+        combined-declared = ["lowest", "highest"]
+        combined-undeclared-first = ["no_strategy", "lowest"]
+        combined-undeclared-last = ["lowest", "no_strategy"]
+        undeclared-default = ["no_strategy"]
+        undeclared-no-default = { features = ["no_strategy"], no-default-feature = true }
+        "#;
+
+        let temp_dir = tempfile::tempdir().unwrap();
+        let workspace = Workspace::from_str(&temp_dir.path().join("pixi.toml"), contents).unwrap();
+
+        assert_eq!(
+            workspace.default_environment().solve_strategy(),
+            pixi_manifest::SolveStrategy::LowestDirect
+        );
+
+        assert_eq!(
+            workspace.environment("lowest").unwrap().solve_strategy(),
+            pixi_manifest::SolveStrategy::Lowest
+        );
+
+        assert_eq!(
+            workspace.environment("highest").unwrap().solve_strategy(),
+            pixi_manifest::SolveStrategy::Highest
+        );
+
+        assert_eq!(
+            workspace
+                .environment("combined-declared")
+                .unwrap()
+                .solve_strategy(),
+            pixi_manifest::SolveStrategy::Lowest
+        );
+
+        assert_eq!(
+            workspace
+                .environment("combined-undeclared-first")
+                .unwrap()
+                .solve_strategy(),
+            pixi_manifest::SolveStrategy::Lowest
+        );
+
+        assert_eq!(
+            workspace
+                .environment("combined-undeclared-last")
+                .unwrap()
+                .solve_strategy(),
+            pixi_manifest::SolveStrategy::Lowest
+        );
+
+        assert_eq!(
+            workspace
+                .environment("undeclared-default")
+                .unwrap()
+                .solve_strategy(),
+            pixi_manifest::SolveStrategy::LowestDirect
+        );
+
+        assert_eq!(
+            workspace
+                .environment("undeclared-no-default")
+                .unwrap()
+                .solve_strategy(),
+            pixi_manifest::SolveStrategy::Highest
+        );
+    }
 }
