@@ -64,7 +64,7 @@ impl GlobModificationTime {
                 Err(e) => {
                     return Err(GlobModificationTimeError::CalculateMTime(
                         matched_path,
-                        std::io::Error::new(std::io::ErrorKind::Other, e.to_string()),
+                        std::io::Error::other(e.to_string()),
                     ));
                 }
             };
