@@ -274,7 +274,7 @@ dependencies = { dummy = "3.11.*" }
 
         // Should create proper quoted section names
         let result = manifest.0.to_string();
-        println!("Result: {}", result);
+        println!("Result: {result}");
         assert!(result.contains("[envs.\"sdl.example\"]"));
     }
 
@@ -296,7 +296,7 @@ dependencies = { dummy = "3.11.*" }
 
         // Should create proper quoted section names
         let result = manifest.0.to_string();
-        println!("get_or_insert_nested_table Result: {}", result);
+        println!("get_or_insert_nested_table Result: {result}");
         // The key should be properly quoted in the section header
         assert!(result.contains("[envs.\"sdl.example\".dependencies]"));
     }
@@ -316,7 +316,7 @@ dependencies = { dummy = "3.11.*" }
         result_table.insert("rich", toml_edit::Item::Value(toml_edit::Value::from("*")));
 
         let result = manifest.0.to_string();
-        println!("Feature with dots result: {}", result);
+        println!("Feature with dots result: {result}");
 
         // Should create [tool.pixi.feature."test.test".dependencies] not [tool.pixi.feature.test.test.dependencies]
         assert!(result.contains("[tool.pixi.feature.\"test.test\".dependencies]"));
@@ -341,7 +341,7 @@ dependencies = { dummy = "3.11.*" }
             .unwrap();
 
         let result = manifest.0.to_string();
-        println!("Feature with dots inline table result: {}", result);
+        println!("Feature with dots inline table result: {result}");
 
         // Should create [tool.pixi.feature."test.test"] with dependencies = { rich = "*" }
         assert!(result.contains("[tool.pixi.feature.\"test.test\"]"));
