@@ -198,6 +198,7 @@ impl TomlManifest {
             channels: None,
 
             channel_priority: workspace.value.channel_priority,
+            solve_strategy: workspace.value.solve_strategy,
 
             system_requirements: self
                 .system_requirements
@@ -391,8 +392,7 @@ impl TomlManifest {
 
             warnings.push(Warning::from(
                 GenericError::new(format!(
-                    "The feature '{}' is defined but not used in any environment. Dependencies of unused features are not resolved or checked, and use wildcard (*) version specifiers by default, disregarding any set `pinning-strategy`",
-                    feature_name
+                    "The feature '{feature_name}' is defined but not used in any environment. Dependencies of unused features are not resolved or checked, and use wildcard (*) version specifiers by default, disregarding any set `pinning-strategy`"
                 ))
                 .with_opt_span(span)
                 .with_help("Remove the feature from the manifest or add it to an environment"),
