@@ -236,7 +236,7 @@ fn gil_disabled(python_record: &PackageRecord) -> Result<bool, PyPITagError> {
             .as_ref()
             .is_some_and(|name| name.as_source() == "python_abi")
             && spec.build.as_ref().is_some_and(|build| {
-                let raw_str = format!("{}", build);
+                let raw_str = format!("{build}");
                 regex.is_match(&raw_str)
             })
     }))
