@@ -25,15 +25,19 @@ def main() -> None:
         default=DEFAULT_DESTINATION_DIR,
         help=f"Destination directory for the executable, default: {DEFAULT_DESTINATION_DIR}",
     )
+    parser.add_argument("--debug", action="store_true", help="Use the debug dir instead of release")
 
+    print(os.environ["CARGO_TARGET_DIR"])
     args = parser.parse_args()
 
+    rel_or_deb = "release" if not args.debug else "debug"
+
     built_executable_path = Path(os.environ["CARGO_TARGET_DIR"]).joinpath(
-        "release", executable_extension("pixi")
+        rel_or_deb, executable_extension("pixi")
     )
     destination_path = args.dest.joinpath(executable_extension(args.name))
 
-    print(f"Copying the executable to {destination_path}")
+    print(f"Copying ({rel_or_deb}) the executable to {destination_path}")
     destination_path.parent.mkdir(parents=True, exist_ok=True)
     shutil.copy(built_executable_path, destination_path)
 
